/****************************************************************************************************
 * Sample code for validating RESTOP                                                                *
 * An SPI digital accelerometer (ADXL362) is connected to the MCU MSP430FR5739                      *
 *                                                                                                  *
 * Citation. If you are using this code for your research please cite:                              *
 *                                                                                                  *
 * [1] A. Rodriguez Arreola, D. Balsamo, G. V. Merrett, and A. S. Weddell, RESTOP: Retaining       *
 *     External Peripheral State in Intermittently-Powered Sensor Systems, Sensors, vol. 18,       *
 *     no. 1, p. 172, Jan. 2018. doi:10.3390/s18010172                                              *
 *                                                                                                  *
 * For more information about this work, direct to: http://www.mdpi.com/1424-8220/18/1/172          *
 * Other parts of the work can be found at: http://www.transient.ecs.soton.ac.uk/                   *
 * Alberto R.A. University of Southampton. All rights reserved.  15/Jan/2018                        *
 * This software is provided "as is", without warranty of any kind, distributed                     *
 * under the terms and conditions of the Creative Commons Attribution (CC BY) license               *
 * (http://creativecommons.org/licenses/by/4.0/).                                                   *
 ****************************************************************************************************/

/**********************************************************************************
 *  In this file, the user declares the registers for Reset a peripheral,
 *	command (for peripherals that need them) and the I2C addres. It is also
 *  defined the size of the instruction history table, the capacitor size,
 *  Vmin and the power and time spent when issuing a peripheral instruction.
***********************************************************************************/

#ifndef CONFIG_H_
#define CONFIG_H_

#endif /* CONFIG_H_ */

#define Table 100  		//Number of locations where to save instructions
#define Cap 0.000020	//Capacitance
#define Vmin 2			//Minimum Voltage

/********************* PERIPHERAL SELECT CONFIGURATION (SPI) **********************
 * CS = 1  P1.3
 * CS = 2  P4.0
 * CS = 3  P2.6
 * CS = 4  P2.1
**********************************************************************************/

/**************************** PERIPHERALS SELECT I2C ****************************
 * CS1 SCL = P1.7   //ADXL_345
 * CS1 SDA = P1.6
*********************************************************************************/

static const unsigned char reg_reset[] = {{0x1F}, {0x30}}; 				//Order: cs1, cs2... Identify when is Reset
static const unsigned char cmd_write[] = {{0x0A}, {0x00}};  			//Order: cs1, cs2... For Writing
static const unsigned char cmd_read [] = {{0x0B}, {0x00}};				//Order: cs1, cs2... For Reading
static const unsigned char i2c_add  [] = {{0x00}, {0xEE}};				//Order: cs1, cs2... Device Address

/*********************** Parameters required to update VR ***************************/		//To be changed in Future Work

static const float pwr_pi[] = {{0.0025}, {0.0025}}; 	//Watts. Order: SPI, I2C. Power to issue an inst.
														//If no SPI: pwr_pi[] = {{0}, {0.0025}};
														//If no I2C: pwr_pi[] = {{0.0025}, {0}};
														//It is needed at least ONE value
//// Time to issue an instruction through SPI ////
static const float Time_spi[] = {{0.0001222}, {0.0000951}, {0.0000684}};	//Seconds. Order: 3params, 2 params, 1 param.
																			//If no value (e.g. no cmmd needed), fill with 0's
//// Time to issue an instruction through I2C ////
static const float Time_i2c[] = {{0.0002126}, {0.0001827}, {0.0001477}};	//Seconds. Order: 3params, 2 params, 1 param.
																			//If no I2C, fill with 0's

/************************************************************************************/
