/****************************************************************************************************
 * Sample code for validating RESTOP                                                                *
 * An SPI digital accelerometer (ADXL362) is connected to the MCU MSP430FR5739                      *
 *                                                                                                  *
 * Citation. If you are using this code for your research please cite:                              *
 *                                                                                                  *
 * [1] A. Rodriguez Arreola, D. Balsamo, G. V. Merrett, and A. S. Weddell, RESTOP: Retaining       *
 *     External Peripheral State in Intermittently-Powered Sensor Systems, Sensors, vol. 18,       *
 *     no. 1, p. 172, Jan. 2018. doi:10.3390/s18010172                                              *
 *                                                                                                  *
 * For more information about this work, direct to: http://www.mdpi.com/1424-8220/18/1/172          *
 * Other parts of the work can be found at: http://www.transient.ecs.soton.ac.uk/                   *
 * Alberto R.A. University of Southampton. All rights reserved.  15/Jan/2018                        *
 * This software is provided "as is", without warranty of any kind, distributed                     *
 * under the terms and conditions of the Creative Commons Attribution (CC BY) license               *
 * (http://creativecommons.org/licenses/by/4.0/).                                                   *
 ****************************************************************************************************/

/************************************************************************
 *	This library declares the functions needed by RESTOP to configure
 *	and obtain data from peripherals and restore their state.
 *
 *  Created on: 20 Jan 2017
************************************************************************/

#include <stdlib.h>
#include <stddef.h>
#include <stdbool.h>

#ifndef H_func_h
#define H_func_h


#endif /* SPI_SETUP_H_ */

#define SPI 0		//SPI Protocol
#define I2C 1		//I2C Protocol

typedef unsigned char   uint8_t;

struct node
{
	uint8_t pcs,	//Bits [7:7] -> Burst Function
					//Bits [6:6] -> Read Function
					//Bits [5:3] -> Preserve flag
					//Bits [2:0] -> Chip select
			cmd,	//Command
			reg,	//Register or Address
			val,	//Value to be written in register
			next,	//Point to the next node
			prev;	//Point to the previous node
	bool	prot;	//Protocol to be used SPI or I2C
};


static void csn1()  {P1OUT &= ~BIT3;};			//Pin where is connected each peripheral
static void cs1 ()  {P1OUT |= BIT3;};
static void csn2()  {P4OUT &= ~BIT0;};
static void cs2 ()  {P4OUT |= BIT0;};
static void csn3()  {P2OUT |= BIT6;};
static void cs3 ()  {P2OUT |= BIT6;};

static void (*chip_select[2])() = {cs1,cs2,cs3};							//Order: cs1, cs2... Disable Peripheral
static void (*chip_selectn[2])() = {csn1,csn2,csn3};						//Order: cs1, cs2... Enable Peripheral


extern void RESTOP_write1(uint8_t, uint8_t, uint8_t, uint8_t, uint8_t);  	//peripheral, command, register, value
extern uint8_t  RESTOP_read1(uint8_t, uint8_t, uint8_t);					//peripheral, command, register
void transmitI2C_init(uint8_t);												//I2C transmit
uint8_t transmitI2C(uint8_t, uint8_t, uint8_t); 							//register, value, operation


extern void SPI_init(void);													//Init the SPI (the user should do it)
extern void RESTOP_write(uint8_t, uint8_t, uint8_t, uint8_t,bool, bool);	//Function to perform write operations
extern void RESTOP_strobe(uint8_t, uint8_t, uint8_t,bool);					//Function to perform strobe isntructions
extern uint8_t RESTOP_read(uint8_t, uint8_t, uint8_t, bool, bool);			//Function to perform read operations
extern void RESTOP_restore(void);											//Function to Restore peripheral state
extern float RESTOP_VR_adj(void);											//Function to adjust VR
