/****************************************************************************************************
 * Sample code for validating RESTOP                                                                *
 * An SPI digital accelerometer (ADXL362) is connected to the MCU MSP430FR5739                      *
 *                                                                                                  *
 * Citation. If you are using this code for your research please cite:                              *
 *                                                                                                  *
 * [1] A. Rodriguez Arreola, D. Balsamo, G. V. Merrett, and A. S. Weddell, RESTOP: Retaining       *
 *     External Peripheral State in Intermittently-Powered Sensor Systems, Sensors, vol. 18,       *
 *     no. 1, p. 172, Jan. 2018. doi:10.3390/s18010172                                              *
 *                                                                                                  *
 * For more information about this work, direct to: http://www.mdpi.com/1424-8220/18/1/172          *
 * Other parts of the work can be found at: http://www.transient.ecs.soton.ac.uk/                   *
 * Alberto R.A. University of Southampton. All rights reserved.  15/Jan/2018                        *
 * This software is provided "as is", without warranty of any kind, distributed                     *
 * under the terms and conditions of the Creative Commons Attribution (CC BY) license               *
 * (http://creativecommons.org/licenses/by/4.0/).                                                   *
 ****************************************************************************************************/


#include <msp430.h>

//#include "hibernation.h"     //Hibernus functionality
#include "Config.h"
#include "RESTOP_func.h"

unsigned int  readX, readY, readZ;

//float Vr;  	//New restore threshold
int main(void)
{

	WDTCTL = WDTPW+WDTHOLD;                   // Stop watchdog timer

	//Hibernus();	//Configures comparator, restores if a snapshot was saved.
					//RESTOP_restore() goes inside this function

	SPI_init();		//SPI Init (to be implemented by user)


	/********************************* PRESERVE FLAG **********************************************************************
	 * 0: The instruction does not have to be saved in the history table (Not-save).
     * 1: The instruction has to be saved in a new element in the table (Save).
     * 2: The issued instruction would replace any other similar previously saved in the history table (Save-but-replace).
 	 * 5: The instruction has to be saved and preserved in the table (Save-Preserve).
 	 * 6: The instruction would replace any other similar previously saved and will be preserved (Save-but-replace-Preserve)
	************************************************************************************************************************/

	/**************************************** SPI ACC********************************************************/
	RESTOP_write(1,2,0x1F,0x52,0,SPI);		//Soft reset
	RESTOP_write(1,1,0x2D,0x02,0,SPI);	    //Measurement Mode
	RESTOP_read(1,1,0x0B,0,SPI);			//STATUS


	while (1)   //32, 64, 128 samples
	{
		readX = RESTOP_read(1,1,0x08,0,SPI);		   //Read X
		readY = RESTOP_read(1,1,0x09,0,SPI);		   //Read Y
		readZ = RESTOP_read(1,1,0x0A,0,SPI);		   //Read Z

	}
	/**************************************** SPI ACC********************************************************/

	//Vr=RESTOP_VR_adj();		This has to be included at the begining of the snapshotting routine of Hibernus.

}
